@@ -139,7 +139,7 @@ class HaproxyPlugin(Plugin):
         self.containers_updated()
 
     @inlineCallbacks
-    def containers_updated(self):
+    def containers_updated(self, *args, **kwargs):
         logger.info('Containers updated: dumping haproxy config.')
         data = yield self.app_controller.list()
         self.proxy_config.dump(data)
