@@ -196,7 +196,6 @@ class DockerTwistedClient(object):
     def inspect(self, id):
         assert not id is None
         r = yield self._get('containers/%s/json' % bytes(id))
-        print r
         r = yield self.collect_json_or_none(r)
         defer.returnValue(r)
 
@@ -241,3 +240,17 @@ class DockerTwistedClient(object):
         ct = yield txhttp.json_content(result)
 
         defer.returnValue(ct['Id'])
+
+    @inlineCallbacks
+    def find_containers_by_names(self, names):
+        result = yield self._get('containers/json?all=1')
+        response = yield txhttp.json_content(result)
+
+        ids = dict([(name, None) for name in names])
+
+        for ct in response:
+            for name in names:
+                if ('/%s' % name) in ct['Names']:
+                    ids[name] = ct['Id']
+
+        defer.returnValue(ids)
